@@ -4,6 +4,7 @@ import os
 from dbnd._core.configuration.environ_config import in_quiet_mode
 from dbnd._core.errors.friendly_error.versioned_dagbag import failed_to_load_versioned_dagbag_plugin
 from dbnd._core.utils.object_utils import patch_module_attr
+from dbnd_airflow.constants import AIRFLOW_VERSION_2
 
 logger = logging.getLogger(__name__)
 
@@ -17,10 +18,10 @@ def _use_databand_airflow_dagbag():
     """
     import airflow
     from airflow import settings
-    if settings.RBAC:
-        from airflow.www_rbac import views
-    else:
+    if AIRFLOW_VERSION_2 or not settings.RBAC:
         from airflow.www import views
+    else:
+        from airflow.www_rbac import views
 
     from dbnd_airflow.web.databand_versioned_dagbag import DbndAirflowDagBag, DbndDagModel
 
@@ -59,8 +60,11 @@ def patch_airflow_create_app():
             return res
 
         return patched_create_app
+    if AIRFLOW_VERSION_2:
+        from airflow.www import app as airflow_app_rbac
+    else:
+        from airflow.www_rbac import app  as airflow_app_rbac
 
-    from airflow.www_rbac import app as airflow_app_rbac
     airflow_app_rbac.create_app = patch_create_app(airflow_app_rbac.create_app)
 
     from airflow.www import app as airflow_app_no_rbac
